@@ -9,20 +9,20 @@ for entry_point in pkg_resources.iter_entry_points(
         entry_point_obj = entry_point.load()
     except BaseException as e:
         warnings.warn(
-            _("Couldn't load {} entry-point {} from {}: {}").format(
+            "Couldn't load {} entry-point {} from {}: {}".format(
                 repr(thunar_plugin_entry_point_name),
                 repr(entry_point.name),
-                repr(entry_point.dist or _("unknown distribution")),
+                repr(entry_point.dist or "unknown distribution"),
                 e,
             )
         )
         continue
     print(
-        _("Found {} entry-point {} ({}) from {}").format(
+        "Found {} entry-point {} ({}) from {}".format(
             repr(thunar_plugin_entry_point_name),
             repr(entry_point.name),
             repr(entry_point_obj),
-            repr(entry_point.dist or _("unknown distribution")),
+            repr(entry_point.dist or "unknown distribution"),
         )
     )
     locals()[entry_point_obj.__name__] = entry_point_obj
